@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-/* $Id: ImageManager.java 1681108 2015-05-22 13:26:12Z ssteiner $ */
+/* $Id: ImageManager.java 1804124 2017-08-04 14:13:54Z ssteiner $ */
 
 package org.apache.xmlgraphics.image.loader;
 
@@ -348,9 +348,8 @@ public class ImageManager {
         ImageInfo info = image.getInfo();
 
         Image img = null;
-        int count = flavors.length;
-        for (int i = 0; i < count; i++) {
-            if (image.getFlavor().equals(flavors[i])) {
+        for (ImageFlavor flavor : flavors) {
+            if (image.getFlavor().equals(flavor)) {
                 //Shortcut (the image is already in one of the requested formats)
                 return image;
             }
